@@ -77,7 +77,7 @@ def use_dill():
     # dill doesn't work with cPickle,
     # tell the two relevant modules to use plain pickle
 
-    global pickle
+    global pickle  # noqa
     pickle = dill
 
     try:
@@ -98,7 +98,7 @@ def use_cloudpickle():
     """
     import cloudpickle
 
-    global pickle
+    global pickle  # noqa
     pickle = cloudpickle
 
     try:
@@ -278,9 +278,9 @@ class CannedArray(CannedObject):
         self.shape = obj.shape
         self.dtype = obj.dtype.descr if obj.dtype.fields else obj.dtype.str
         self.pickled = False
-        if sum(obj.shape) == 0:
+        if sum(obj.shape) == 0:  # noqa
             self.pickled = True
-        elif obj.dtype == "O":
+        elif obj.dtype == "O":  # noqa
             # can't handle object dtype with buffer approach
             self.pickled = True
         elif obj.dtype.fields and any(dt == "O" for dt, sz in obj.dtype.fields.values()):
